### Version 0.6.2 (2014-10-30)

  - docker: install pyannote.server from source

### Version 0.6 (2014-10-30)

  - switch to pyannote.parser 0.2
  - switch to flask-cors

### Version 0.5 (2014-10-24)

  - breaking change: new PyAnnote JSON format

### Version 0.4.1 (2014-10-01)

  - fix pyannote.metrics version requirement

### Version 0.4 (2014-09-30)

  - rebranding to pyannote.server

### Version 0.3 (2014-04-04)

  - /segmentation routes
